

-- app de proagrp
CREATE DATABASE db_app_arandano
GO

USE  db_app_arandano

-- TABLAS  
create table general
(
	general_id INT NOT NULL IDENTITY(1,1) PRIMARY KEY,
	general_fecha VARCHAR(20) NOT NULL,
	general_hora VARCHAR(20) NOT NULL,
	general_lote VARCHAR(200) NOT NULL,
	general_turno VARCHAR(20) NOT NULL,
	general_variedad VARCHAR(150) NOT NULL,
	general_horario VARCHAR(30)  NOT NULL,
	general_dni_jefe_grupo  VARCHAR(100)  NOT NULL,
	general_dato_jefe_grupo VARCHAR(200) NOT NULL,
	general_dni_jefe_cuadrilla VARCHAR(50) NOT NULL,
	general_dato_jefe_cuadrilla VARCHAR(200) NOT NULL,
	general_dni_cosechador VARCHAR(50) NOT NULL,
	general_dato_cosechador VARCHAR(200) NOT NULL,
	general_kg_exportable VARCHAR(50) NOT NULL,
	general_kg_descarte VARCHAR(50)  NOT NULL
)
GO

CREATE TABLE sucursal
(
	sucursal_id INT NOT NULL PRIMARY KEY IDENTITY(1,1),
	sucursal_nombre VARCHAR(20) NOT NULL,
	sucursal_direccion VARCHAR(100) NOT NULL,
	sucursal_fecha_creacion DATETIME NOT NULL,
	sucursal_estado  BIT NOT NULL
)
GO

CREATE TABLE fundo
(
	fundo_id  INT NOT NULL PRIMARY KEY IDENTITY(1,1),
	fundo_nombre VARCHAR(30) NOT NULL,
	fundo_direccion VARCHAR(100) NOT NULL,
	fundo_fecha_creacion DATETIME NOT NULL,
	fundo_estado BIT NOT NULL,

	fundo_sucursal_id INT NOT NULL,
	CONSTRAINT kf_fundo_sucursal FOREIGN KEY (fundo_sucursal_id) REFERENCES sucursal(sucursal_id)
)
GO

CREATE TABLE lote
(
)
GO

--  PROCEDURES 
ALTER  PROC sp_insertar_general
	@general_fecha VARCHAR(20),
	@general_hora VARCHAR(20),
	@general_lote VARCHAR(200),
	@general_turno VARCHAR(20),
	@general_variedad VARCHAR(150),
	@general_horario VARCHAR(30),
	@general_dni_jefe_grupo  VARCHAR(100),
	@general_dato_jefe_grupo VARCHAR(200),
	@general_dni_jefe_cuadrilla VARCHAR(50),
	@general_dato_jefe_cuadrilla VARCHAR(200),
	@general_dni_cosechador VARCHAR(50),
	@general_dato_cosechador VARCHAR(200),
	@general_kg_exportable VARCHAR(50),
	@general_kg_descarte VARCHAR(50)  
AS
	BEGIN
		-- verificamos si existe el registro
		IF EXISTS (
				SELECT  * FROM general
				WHERE general_fecha=@general_fecha 
				AND general_hora=@general_hora 
				AND general_lote=@general_lote 
				AND general_turno=@general_turno 
				AND general_variedad=@general_variedad 
				AND general_horario=@general_horario
				AND general_dni_jefe_grupo=@general_dni_jefe_grupo 
				AND general_dato_jefe_grupo=@general_dato_jefe_grupo
				AND general_dni_jefe_cuadrilla=@general_dni_jefe_cuadrilla  
				AND general_dato_jefe_cuadrilla=@general_dato_jefe_cuadrilla 
				AND general_dni_cosechador=@general_dni_cosechador
				AND general_dato_cosechador=@general_dato_cosechador 
				AND general_kg_exportable=@general_kg_exportable
		)
			BEGIN 
				-- si el registro existe actualzamos datos
				UPDATE general
				SET 
					general_fecha = @general_fecha,
					general_hora = @general_hora,
					general_lote = @general_lote,
					general_turno = @general_turno,
					general_variedad = @general_variedad,
					general_horario = @general_horario,
					general_dni_jefe_grupo = @general_dni_jefe_grupo,
					general_dato_jefe_grupo = @general_dato_jefe_grupo,
					general_dni_jefe_cuadrilla = @general_dni_jefe_cuadrilla,
					general_dato_jefe_cuadrilla = @general_dato_jefe_cuadrilla,
					general_dni_cosechador = @general_dni_cosechador,
					general_dato_cosechador = @general_dato_cosechador,
					general_kg_exportable = @general_kg_exportable,
					general_kg_descarte = @general_kg_descarte
				WHERE 
					general_fecha=@general_fecha 
					AND general_hora=@general_hora 
					AND general_lote=@general_lote 
					AND general_turno=@general_turno 
					AND general_variedad=@general_variedad 
					AND general_horario=@general_horario
					AND general_dato_jefe_grupo=@general_dni_jefe_grupo 
					AND general_dato_jefe_grupo=@general_dato_jefe_grupo
					AND general_dni_jefe_cuadrilla=@general_dni_jefe_cuadrilla  
					AND general_dato_jefe_cuadrilla=@general_dato_jefe_cuadrilla 
					AND general_dni_cosechador=@general_dni_cosechador
					AND general_dato_cosechador=@general_dato_cosechador 
			END
		ELSE
			BEGIN
				-- Si el registro no existe, inserta uno nuevo
				INSERT INTO general(general_fecha,general_hora,general_lote,general_turno,general_variedad,general_horario,general_dni_jefe_grupo,general_dato_jefe_grupo,general_dni_jefe_cuadrilla,general_dato_jefe_cuadrilla,general_dni_cosechador,general_dato_cosechador,general_kg_exportable,general_kg_descarte)
				VALUES(@general_fecha,@general_hora,@general_lote,@general_turno,@general_variedad,@general_horario,@general_dni_jefe_grupo,@general_dato_jefe_grupo,@general_dni_jefe_cuadrilla,@general_dato_jefe_cuadrilla,@general_dni_cosechador,@general_dato_cosechador,@general_kg_exportable,@general_kg_descarte)
			END
	END
GO

-- procedure  buscar cosechadro  por DNI
ALTER PROC sp_buscar_cosechador
	@general_dni_cosechador VARCHAR(50),
	@general_fecha VARCHAR(20)
AS
	BEGIN
		SELECT p.general_id,
		-- Convertimos la columna general_fecha desde nmero de serie a formato de fecha
		FORMAT(DATEADD(DAY, CAST(p.general_fecha AS INT), '1899-12-30'), 'dd/MM/yyyy') AS general_fecha,  
		p.general_hora,p.general_lote,
		p.general_turno,p.general_variedad,p.general_horario,p.general_dni_jefe_grupo,
		p.general_dato_jefe_grupo,p.general_dni_jefe_cuadrilla,p.general_dato_jefe_cuadrilla,
		p.general_dni_cosechador,p.general_dato_cosechador,
		p.general_kg_descarte,
		SUM(CAST(p.general_kg_exportable AS DECIMAL(18,2))) AS total_kg_exportable,
		COUNT(p.general_kg_exportable) AS total_registro
		FROM  general AS p
		WHERE  general_dni_cosechador = @general_dni_cosechador  
		AND FORMAT(DATEADD(DAY, CAST(general_fecha AS INT), '1899-12-30'), 'dd-MM-yyyy') = @general_fecha
		GROUP BY 
        p.general_id,
		FORMAT(DATEADD(DAY, CAST(p.general_fecha AS INT), '1899-12-30'), 'dd/MM/yyyy'),
        p.general_hora,
        p.general_lote,
        p.general_turno,
        p.general_variedad,
        p.general_horario,
        p.general_dni_jefe_grupo,
        p.general_dato_jefe_grupo,
        p.general_dni_jefe_cuadrilla,
        p.general_dato_jefe_cuadrilla,
        p.general_dni_cosechador,
        p.general_dato_cosechador,
        p.general_kg_descarte
	END
GO


select * from general